==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Homepage vum Site',
'articles' => 'Artikelen',
'articles_auteur' => 'Artikelen vun d&euml;sem Auteur',
'articles_populaires' => 'D&eacute;i bel&eacute;iwsten Artikelen',
'articles_rubrique' => 'Artikelen aus d&euml;ser Rubrik',
'aucun_article' => 'Et g&euml;tt keen Artikel op d&euml;ser Adress',
'aucun_auteur' => 'Et g&euml;tt keen Auteur op d&euml;ser Adress',
'aucun_site' => 'Et g&euml;tt keen Site op d&euml;ser Adress',
'aucune_breve' => 'Et g&euml;tt keng Kuerzmeldung op d&euml;ser Adress',
'aucune_rubrique' => 'Et g&euml;tt keng Rubrik op d&euml;ser Adress',
'autres' => 'Anerer',
'autres_breves' => 'Aner Kuerzmeldungen',
'autres_groupes_mots_clefs' => 'Aner Schl&euml;sselwierder-Gruppen',
'autres_sites' => 'Aner Siten',

// B
'bonjour' => 'Bonjour',
'breves' => 'Kuerzmeldungen',

// C
'commenter_site' => 'D&euml;sen Site komment&eacute;ieren',

// D
'date' => 'Datum',
'dernier_ajout' => 'L&auml;scht &Auml;nnerung',
'dernieres_breves' => 'L&auml;scht Kuerzmeldungen',
'derniers_articles' => 'L&auml;scht Artikelen',
'derniers_commentaires' => 'L&auml;scht Commentairen',
'derniers_messages_forum' => 'L&auml;scht Messagen aus de Forum\'en',

// E
'edition_mode_texte' => 'Editioun am Text-Modus vun',
'en_reponse' => 'Als &Auml;ntwert un:',
'en_resume' => 'Am R&eacute;sum&eacute;',
'envoyer_message' => 'E Message sch&eacute;cken',
'espace_prive' => 'Privaten Deel',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Struktur vum Site',

// J
'jours' => 'Deg',

// L
'lien_connecter' => 'Verbannen',

// M
'meme_auteur' => 'Vum selwechten Auteur',
'meme_rubrique' => 'An der selwechter Rubrik',
'memes_auteurs' => 'Vun de selwechten Auteuren',
'message' => 'Message',
'messages_forum' => 'Messagen vum Forum',
'messages_recents' => 'L&auml;scht Messagen aus de Forum\'en',
'mots_clefs' => 'Schl&euml;sselwierder',
'mots_clefs_meme_groupe' => 'Schl&euml;sselwierder vum selwechten Grupp',

// N
'navigation' => 'Navigatioun',
'nom' => 'Numm',
'nouveautes' => 'Neiegkeeten',
'nouveautes_web' => 'Internet-Neiegkeeten',
'nouveaux_articles' => 'Nei Artikelen',
'nouvelles_breves' => 'Nei Kuerzmeldungen',

// P
'page_precedente' => 'l&auml;scht S&auml;it',
'page_suivante' => 'n&auml;chst S&auml;it',
'par_auteur' => 'vum',
'participer_site' => 'Dir k&euml;nnt un d&euml;sem Site matschaffen an &auml;r Artikelen propos&eacute;ieren andem der Iech hei aschreiwt. Dir kritt direkt en Email mat &auml;rem Login fir de privaten Deel vum Site.',
'plan_site' => 'Plang vum Site',
'popularite' => 'Popularit&eacute;it',
'poster_message' => 'E Message sch&eacute;cken',
'proposer_site' => 'Dir k&euml;nnt e Site fir d&euml;s Rubrik uginn:',

// R
'repondre_article' => 'Op d&euml;sen Artikel &auml;ntweren',
'repondre_breve' => 'Op d&euml;s Kuerzmeldung &auml;ntweren',
'repondre_message' => 'Op d&euml;sen Message &auml;ntweren',
'resultats_recherche' => 'Resultater vun der Sich',
'retour_debut_forums' => 'Zer&euml;ck op den Ufank vun de Forum\'en',
'rubrique' => 'Rubrik',
'rubriques' => 'Rubriken',

// S
'signatures_petition' => '&Euml;nnerschr&euml;ften',
'site_realise_avec_spip' => 'D&euml;se Site ass mat SPIP realis&eacute;iert',
'sites_web' => 'Internet-Siten',
'sous_rubriques' => '&Euml;nner-Rubriken',
'spam' => 'Spam',
'suite' => 'weider',
'sur_web' => 'Um Internet',
'syndiquer_rubrique' => 'D&euml;s Rubrik syndiqu&eacute;ieren',
'syndiquer_site' => 'De ganzen Site syndiqu&eacute;ieren',

// T
'texte_lettre_information' => 'Hei ass d\'Newsletter vum Site',
'texte_lettre_information_2' => 'D&euml;s Newsletter ass eng L&euml;scht vun den Artikelen a Kuerzmeldungen z&euml;nter',

// V
'ver_imprimer' => 'Drock-Versioun',
'voir_en_ligne' => 'Online gesinn',
'voir_squelette' => 'd\'Skelett vun d&euml;ser S&auml;it weisen'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Homepage vum Site',
'article' => 'Article', # NEW
'articles' => 'Artikelen',
'articles_auteur' => 'Artikelen vun d&euml;sem Auteur',
'articles_populaires' => 'D&eacute;i bel&eacute;iwsten Artikelen',
'articles_rubrique' => 'Artikelen aus d&euml;ser Rubrik',
'aucun_article' => 'Et g&euml;tt keen Artikel op d&euml;ser Adress',
'aucun_auteur' => 'Et g&euml;tt keen Auteur op d&euml;ser Adress',
'aucun_site' => 'Et g&euml;tt keen Site op d&euml;ser Adress',
'aucune_breve' => 'Et g&euml;tt keng Kuerzmeldung op d&euml;ser Adress',
'aucune_rubrique' => 'Et g&euml;tt keng Rubrik op d&euml;ser Adress',
'auteur' => 'Auteur', # NEW
'autres' => 'Anerer',
'autres_breves' => 'Aner Kuerzmeldungen',
'autres_groupes_mots_clefs' => 'Aner Schl&euml;sselwierder-Gruppen',
'autres_sites' => 'Aner Siten',

// B
'bonjour' => 'Bonjour',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Kuerzmeldungen',

// C
'commenter_site' => 'D&euml;sen Site komment&eacute;ieren',
'copie_document_impossible' => 'Onm&eacute;iglech dat Dokument ze kop&eacute;ieren',

// D
'date' => 'Datum',
'dernier_ajout' => 'L&auml;scht &Auml;nnerung',
'dernieres_breves' => 'L&auml;scht Kuerzmeldungen',
'derniers_articles' => 'L&auml;scht Artikelen',
'derniers_commentaires' => 'L&auml;scht Commentairen',
'derniers_messages_forum' => 'L&auml;scht Messagen aus de Forum\'en',
'documents_interdits_forum' => 'Dokumenter sinn am Forum n&euml;t erlaabt',

// E
'edition_mode_texte' => 'Editioun am Text-Modus vun',
'en_reponse' => 'Als &Auml;ntwert un:',
'en_resume' => 'Am R&eacute;sum&eacute;',
'envoyer_message' => 'E Message sch&eacute;cken',
'espace_prive' => 'Privaten Deel',

// F
'formats_acceptes' => 'Akzept&eacute;iert Formater: @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Struktur vum Site',

// J
'jours' => 'Deg',

// L
'lien_connecter' => 'Verbannen',

// M
'meme_auteur' => 'Vum selwechten Auteur',
'meme_rubrique' => 'An der selwechter Rubrik',
'memes_auteurs' => 'Vun de selwechten Auteuren',
'message' => 'Message',
'messages_forum' => 'Messagen vum Forum',
'messages_recents' => 'L&auml;scht Messagen aus de Forum\'en',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Schl&euml;sselwierder',
'mots_clefs_meme_groupe' => 'Schl&euml;sselwierder vum selwechten Grupp',

// N
'navigation' => 'Navigatioun',
'nom' => 'Numm',
'nouveautes' => 'Neiegkeeten',
'nouveautes_web' => 'Internet-Neiegkeeten',
'nouveaux_articles' => 'Nei Artikelen',
'nouvelles_breves' => 'Nei Kuerzmeldungen',

// P
'page_precedente' => 'l&auml;scht S&auml;it',
'page_suivante' => 'n&auml;chst S&auml;it',
'par_auteur' => 'vum',
'participer_site' => 'Dir k&euml;nnt un d&euml;sem Site matschaffen an &auml;r Artikelen propos&eacute;ieren andem der Iech hei aschreiwt. Dir kritt direkt en Email mat &auml;rem Login fir de privaten Deel vum Site.',
'plan_site' => 'Plang vum Site',
'popularite' => 'Popularit&eacute;it',
'poster_message' => 'E Message sch&eacute;cken',
'proposer_site' => 'Dir k&euml;nnt e Site fir d&euml;s Rubrik uginn:',

// R
'repondre_article' => 'Op d&euml;sen Artikel &auml;ntweren',
'repondre_breve' => 'Op d&euml;s Kuerzmeldung &auml;ntweren',
'repondre_message' => 'Op d&euml;sen Message &auml;ntweren',
'resultats_recherche' => 'Resultater vun der Sich',
'retour_debut_forums' => 'Zer&euml;ck op den Ufank vun de Forum\'en',
'rubrique' => 'Rubrik',
'rubriques' => 'Rubriken',

// S
'signatures_petition' => '&Euml;nnerschr&euml;ften',
'site_realise_avec_spip' => 'D&euml;se Site ass mat SPIP realis&eacute;iert',
'sites_web' => 'Internet-Siten',
'sous_rubriques' => '&Euml;nner-Rubriken',
'spam' => 'Spam',
'suite' => 'weider',
'sur_web' => 'Um Internet',
'syndiquer_rubrique' => 'D&euml;s Rubrik syndiqu&eacute;ieren',
'syndiquer_site' => 'De ganzen Site syndiqu&eacute;ieren',

// T
'texte_lettre_information' => 'Hei ass d\'Newsletter vum Site',
'texte_lettre_information_2' => 'D&euml;s Newsletter ass eng L&euml;scht vun den Artikelen a Kuerzmeldungen z&euml;nter',

// V
'ver_imprimer' => 'Drock-Versioun',
'voir_en_ligne' => 'Online gesinn',
'voir_squelette' => 'd\'Skelett vun d&euml;ser S&auml;it weisen'
);

?>
